@@ -1,7 +1,7 @@
 """
 Type annotations for sts service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
 
 Usage::
 
@@ -54,8 +54,8 @@ class Exceptions:
 
 class STSClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
     """
 
     meta: ClientMeta
@@ -63,6 +63,7 @@ class STSClient:
 
     def assume_role(
         self,
+        *,
         RoleArn: str,
         RoleSessionName: str,
         PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
@@ -73,54 +74,56 @@ class STSClient:
         ExternalId: str = None,
         SerialNumber: str = None,
         TokenCode: str = None,
-        SourceIdentity: str = None,
+        SourceIdentity: str = None
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.assume_role)
-        [Show boto3-stubs documentation](./client.md#assume_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role)
         """
 
     def assume_role_with_saml(
         self,
+        *,
         RoleArn: str,
         PrincipalArn: str,
         SAMLAssertion: str,
         PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
         Policy: str = None,
-        DurationSeconds: int = None,
+        DurationSeconds: int = None
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.assume_role_with_saml)
-        [Show boto3-stubs documentation](./client.md#assume_role_with_saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_saml)
         """
 
     def assume_role_with_web_identity(
         self,
+        *,
         RoleArn: str,
         RoleSessionName: str,
         WebIdentityToken: str,
         ProviderId: str = None,
         PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
         Policy: str = None,
-        DurationSeconds: int = None,
+        DurationSeconds: int = None
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
-        [Show boto3-stubs documentation](./client.md#assume_role_with_web_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can_paginate)
         """
 
     def decode_authorization_message(
-        self, EncodedMessage: str
+        self, *, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.decode_authorization_message)
-        [Show boto3-stubs documentation](./client.md#decode_authorization_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode_authorization_message)
         """
 
     def generate_presigned_url(
@@ -131,39 +134,40 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate_presigned_url)
         """
 
-    def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
+    def get_access_key_info(self, *, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.get_access_key_info)
-        [Show boto3-stubs documentation](./client.md#get_access_key_info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.get_caller_identity)
-        [Show boto3-stubs documentation](./client.md#get_caller_identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_caller_identity)
         """
 
     def get_federation_token(
         self,
+        *,
         Name: str,
         Policy: str = None,
         PolicyArns: List[PolicyDescriptorTypeTypeDef] = None,
         DurationSeconds: int = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List[TagTypeDef] = None
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.get_federation_token)
-        [Show boto3-stubs documentation](./client.md#get_federation_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_federation_token)
         """
 
     def get_session_token(
-        self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
+        self, *, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.86/reference/services/sts.html#STS.Client.get_session_token)
-        [Show boto3-stubs documentation](./client.md#get_session_token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.90/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get_session_token)
         """
